FanInChoreography

Trait FanInChoreography 

pub trait FanInChoreography<V> {
    type L: LocationSet;
    type QS: LocationSet;
    type RS: LocationSet;

    // Required method
    fn run<Q, QSSubsetL, RSSubsetL, QMemberL, QMemberQS>(
        &self,
        op: &impl ChoreoOp<Self::L>,
    ) -> MultiplyLocated<V, Self::RS>
       where Self::QS: Subset<Self::L, QSSubsetL>,
             Self::RS: Subset<Self::L, RSSubsetL>,
             Q: Member<Self::L, QMemberL> + Member<Self::QS, QMemberQS> + ChoreographyLocation;
}
Special choreography for fanin

Required Associated Types

type L: LocationSet

All locations involved in the choreography

type QS: LocationSet

Locations looping over

type RS: LocationSet

Recipient locations

Required Methods

fn run<Q, QSSubsetL, RSSubsetL, QMemberL, QMemberQS>( &self, op: &impl ChoreoOp<Self::L>, ) -> MultiplyLocated<V, Self::RS>
where Self::QS: Subset<Self::L, QSSubsetL>, Self::RS: Subset<Self::L, RSSubsetL>, Q: Member<Self::L, QMemberL> + Member<Self::QS, QMemberQS> + ChoreographyLocation,

The body of the choreography defined in terms of the operators provided by ChoreoOp

Q is the location that the loop variable and is guaranteed to be a member of L and QS.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors